==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/zh_TW.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "平均負載",
    "Last minute" : "最後一分鐘",
    "Memory info not available" : "記憶體資訊暫時無法使用",
    "Total" : "總計",
    "Current usage" : "目前使用量",
    "Users" : "使用者",
    "Groups" : "群組",
    "Links" : "連結",
    "Federated sent" : "聯盟發送",
    "Federated received" : "聯盟接收",
    "Last 24 hours" : "24小時前",
    "Last 1 hour" : "1小時前",
    "Last 5 mins" : "5分鐘前",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "CPU load" : "CPU負載",
    "Memory usage" : "記憶體使用量",
    "Active users" : "活動中用戶",
    "Shares" : "分享",
    "Storage" : "儲存",
    "Users:" : "使用者:",
    "Files:" : "檔案:",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Nextcloud" : "Nextcloud",
    "Version:" : "版本:",
    "Apps installed:" : "已安裝應用程式：",
    "Apps updates available:" : "可升級的應用程式：",
    "PHP" : "PHP",
    "Memory Limit:" : "記憶體限制:",
    "Max Execution Time:" : "最大執行時間:",
    "Upload max size:" : "上傳至多:",
    "Database" : "資料庫",
    "Type:" : "類型:",
    "Size:" : "大小:",
    "External monitoring tool" : "外部監控工具",
    "You can connect an external monitoring tool by using this end point:" : "您可以使用此終端連接外部監視工具："
},
"nplurals=1; plural=0;");

==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/zh_TW.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "平均負載",
    "Last minute" : "最後一分鐘",
    "Memory info not available" : "記憶體資訊暫時無法使用",
    "Total" : "總計",
    "Current usage" : "目前使用量",
    "Users" : "使用者",
    "Groups" : "群組",
    "Links" : "連結",
    "Federated sent" : "聯盟發送",
    "Federated received" : "聯盟接收",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "Files:" : "檔案:",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Active users" : "活動中用戶",
    "Shares" : "分享",
    "PHP" : "PHP",
    "Version:" : "版本:",
    "Memory Limit:" : "記憶體限制:",
    "Max Execution Time:" : "最大執行時間:",
    "Upload max size:" : "上傳至多:",
    "Database" : "資料庫",
    "Type:" : "類型:",
    "Size:" : "大小:",
    "External monitoring tool" : "外部監控工具",
    "You can connect an external monitoring tool by using this end point:" : "您可以使用此終端連接外部監視工具：",
    "Last 24 hours" : "24小時前",
    "Last 1 hour" : "1小時前",
    "Last 5 mins" : "5分鐘前",
    "CPU load" : "CPU負載",
    "Memory usage" : "記憶體使用量",
    "Storage" : "儲存",
    "Users:" : "使用者:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "已安裝應用程式：",
    "Apps updates available:" : "可升級的應用程式："
},
"nplurals=1; plural=0;");
